==> kbibtex-trinity_3.5.13.2.orig.tar.xz: kbibtex-trinity-3.5.13.2/src/messagehandler.h <==
/***************************************************************************
    copyright            : (C) 2005-2006 by Robby Stephenson
    email                :  robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This file has been modified to match the requirements of KBibTeX.     *
 *   In case of problems or bugs arising from this implementation, please  *
 *   contact the KBibTeX team first.                                       *
 *                             Thomas Fischer <fischer@unix-ag.uni-kl.de>  *
 *                                                                         *
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#ifndef KBIBTEX_MESSAGEHANDLER_H
#define KBIBTEX_MESSAGEHANDLER_H

class QString;
class QStringList;

namespace KBibTeX {

/**
 * @author Robby Stephenson
 */
class MessageHandler {
public:
  enum Type { Status, Warning, Error, ListError };

  MessageHandler() {}
  virtual ~MessageHandler() {}

  virtual void send(const QString& message, Type type) = 0;
  virtual void infoList(const QString& message, const QStringList& list) = 0;
};

class ManagerMessage : public MessageHandler {
public:
  ManagerMessage() : MessageHandler() {}
  virtual ~ManagerMessage() {}

  virtual void send(const QString& message, Type type);
  virtual void infoList(const QString& message, const QStringList& list);
};

} // end namespace

#endif

==> kbibtex-trinity_14.1.6~pre1.orig.tar.xz: kbibtex-trinity-14.1.6~pre1+36708319/src/messagehandler.h <==
/***************************************************************************
    copyright            : (C) 2005-2006 by Robby Stephenson
    email                :  robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This file has been modified to match the requirements of KBibTeX.     *
 *   In case of problems or bugs arising from this implementation, please  *
 *   contact the KBibTeX team first.                                       *
 *                             Thomas Fischer <fischer@unix-ag.uni-kl.de>  *
 *                                                                         *
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#ifndef KBIBTEX_MESSAGEHANDLER_H
#define KBIBTEX_MESSAGEHANDLER_H

class TQString;
class TQStringList;

namespace KBibTeX {

/**
 * @author Robby Stephenson
 */
class MessageHandler {
public:
  enum Type { Status, Warning, Error, ListError };

  MessageHandler() {}
  virtual ~MessageHandler() {}

  virtual void send(const TQString& message, Type type) = 0;
  virtual void infoList(const TQString& message, const TQStringList& list) = 0;
};

class ManagerMessage : public MessageHandler {
public:
  ManagerMessage() : MessageHandler() {}
  virtual ~ManagerMessage() {}

  virtual void send(const TQString& message, Type type);
  virtual void infoList(const TQString& message, const TQStringList& list);
};

} // end namespace

#endif
